PitCommand

Enum PitCommand 

pub enum PitCommand {
    Clear,
    TearOff,
    Fuel(Option<i16>),
    LF(Option<i16>),
    RF(Option<i16>),
    LR(Option<i16>),
    RR(Option<i16>),
    ClearTires,
    FastRepair,
    ClearWS,
    ClearFR,
    ClearFuel,
}

Variants



Clear

Clear all pit checkboxes



TearOff

WS: Clean the winshield, using one tear off



Fuel(Option<i16>)

Add fuel, optionally specify the amount to add in liters



LF(Option<i16>)

Change the left front tire, optionally specifying the pressure in KPa



RF(Option<i16>)

Change the right front tire, optionally specifying the pressure in KPa



LR(Option<i16>)

Change the left rear tire, optionally specifying the pressure in KPa



RR(Option<i16>)

Change the right rear tire, optionally specifying the pressure in KPa



ClearTires

Clear tire pit checkboxes



FastRepair

FR: Request a fast repair



ClearWS

Uncheck Clean the winshield checkbox



ClearFR

Uncheck request a fast repair



ClearFuel

Uncheck add fuel