pub enum TelemCommand {
Stop = 0,
Start = 1,
Restart = 2,
}Expand description
You can call this any time, but telemtry only records when driver is in there car
Variants
Stop = 0
Turn telemetry recording off
Start = 1
Turn telemetry recording on
Restart = 2
Write current file to disk and start a new one